summaryrefslogtreecommitdiff
path: root/src/depot_cmd.cpp
diff options
context:
space:
mode:
authorMichael Lutz <michi@icosahedron.de>2021-11-14 16:39:17 +0100
committerMichael Lutz <michi@icosahedron.de>2021-12-16 22:28:32 +0100
commit6fe445e6c0fa3163aba48b1ec6d810b6594777bd (patch)
tree320cd8d2d76b38ee06f9fde07ea349adeb3f228a /src/depot_cmd.cpp
parent21675ec7e22bfe53f20300cc27b4d50c84aeb4dc (diff)
downloadopenttd-6fe445e6c0fa3163aba48b1ec6d810b6594777bd.tar.xz
Codechange: Un-bitstuff station/depot/waypoint commands.
Diffstat (limited to 'src/depot_cmd.cpp')
-rw-r--r--src/depot_cmd.cpp8
1 files changed, 3 insertions, 5 deletions
diff --git a/src/depot_cmd.cpp b/src/depot_cmd.cpp
index 1ffaeb70b..294de69e3 100644
--- a/src/depot_cmd.cpp
+++ b/src/depot_cmd.cpp
@@ -39,15 +39,13 @@ static bool IsUniqueDepotName(const std::string &name)
/**
* Rename a depot.
* @param flags type of operation
* @param tile unused
* @param p1 id of depot
* @param p2 unused
* @param text the new name or an empty string when resetting to the default
* @return the cost of this operation or an error
*/
-CommandCost CmdRenameDepot(DoCommandFlag flags, TileIndex tile, uint32 p1, uint32 p2, const std::string &text)
+CommandCost CmdRenameDepot(DoCommandFlag flags, DepotID depot_id, const std::string &text)
{
- Depot *d = Depot::GetIfValid(p1);
+ Depot *d = Depot::GetIfValid(depot_id);
if (d == nullptr) return CMD_ERROR;
CommandCost ret = CheckTileOwnership(d->xy);
@@ -39,15 +39,13 @@ static bool IsUniqueDepotName(const std::string &name)
* Rename a depot.
* @param flags type of operation
- * @param tile unused
- * @param p1 id of depot
- * @param p2 unused
+ * @param depot_id id of depot
* @param text the new name or an empty string when resetting to the default
* @return the cost of this operation or an error